@@ -19,7 +19,7 @@ import (
 	"github.com/go-task/task/v3/internal/logger"
 	"github.com/go-task/task/v3/internal/sort"
 	ver "github.com/go-task/task/v3/internal/version"
-	"github.com/go-task/task/v3/taskfile"
+	"github.com/go-task/task/v3/taskfile/ast"
 )
 
 const usage = `Usage: task [flags...] [task...]
@@ -68,7 +68,7 @@ var flags struct {
 	concurrency int
 	dir         string
 	entrypoint  string
-	output      taskfile.Output
+	output      ast.Output
 	color       bool
 	interval    time.Duration
 	global      bool
@@ -140,7 +140,7 @@ func run() error {
 	pflag.BoolVar(&flags.experiments, "experiments", false, "Lists all the available experiments and whether or not they are enabled.")
 
 	// Gentle force experiment will override the force flag and add a new force-all flag
-	if experiments.GentleForce {
+	if experiments.GentleForce.Enabled {
 		pflag.BoolVarP(&flags.force, "force", "f", false, "Forces execution of the directly called task.")
 		pflag.BoolVar(&flags.forceAll, "force-all", false, "Forces execution of the called task and all its dependant tasks.")
 	} else {
@@ -148,7 +148,7 @@ func run() error {
 	}
 
 	// Remote Taskfiles experiment will adds the "download" and "offline" flags
-	if experiments.RemoteTaskfiles {
+	if experiments.RemoteTaskfiles.Enabled {
 		pflag.BoolVar(&flags.download, "download", false, "Downloads a cached version of a remote Taskfile.")
 		pflag.BoolVar(&flags.offline, "offline", false, "Forces Task to only use local or cached Taskfiles.")
 		pflag.DurationVar(&flags.timeout, "timeout", time.Second*10, "Timeout for downloading remote Taskfiles.")
@@ -291,8 +291,8 @@ func run() error {
 	}
 
 	var (
-		calls   []taskfile.Call
-		globals *taskfile.Vars
+		calls   []ast.Call
+		globals *ast.Vars
 	)
 
 	tasksAndVars, cliArgs, err := getArgs()
@@ -300,19 +300,15 @@ func run() error {
 		return err
 	}
 
-	if e.Taskfile.Version.Compare(taskfile.V3) >= 0 {
-		calls, globals = args.ParseV3(tasksAndVars...)
-	} else {
-		calls, globals = args.ParseV2(tasksAndVars...)
-	}
+	calls, globals = args.Parse(tasksAndVars...)
 
 	// If there are no calls, run the default task instead
 	if len(calls) == 0 {
-		calls = append(calls, taskfile.Call{Task: "default", Direct: true})
+		calls = append(calls, ast.Call{Task: "default"})
 	}
 
-	globals.Set("CLI_ARGS", taskfile.Var{Value: cliArgs})
-	globals.Set("CLI_FORCE", taskfile.Var{Value: flags.force || flags.forceAll})
+	globals.Set("CLI_ARGS", ast.Var{Value: cliArgs})
+	globals.Set("CLI_FORCE", ast.Var{Value: flags.force || flags.forceAll})
 	e.Taskfile.Vars.Merge(globals)
 
 	if !flags.watch {
