@@ -6,6 +6,7 @@ import (
 	"strings"
 	"text/template"
 
+	"github.com/davecgh/go-spew/spew"
 	"mvdan.cc/sh/v3/shell"
 	"mvdan.cc/sh/v3/syntax"
 
@@ -52,6 +53,25 @@ func init() {
 		"relPath": func(basePath, targetPath string) (string, error) {
 			return filepath.Rel(basePath, targetPath)
 		},
+		"merge": func(base map[string]any, v ...map[string]any) map[string]any {
+			cap := len(v)
+			for _, m := range v {
+				cap += len(m)
+			}
+			result := make(map[string]any, cap)
+			for k, v := range base {
+				result[k] = v
+			}
+			for _, m := range v {
+				for k, v := range m {
+					result[k] = v
+				}
+			}
+			return result
+		},
+		"spew": func(v any) string {
+			return spew.Sdump(v)
+		},
 	}
 	// Deprecated aliases for renamed functions.
 	taskFuncs["FromSlash"] = taskFuncs["fromSlash"]
